@@ -1,5 +1,5 @@
 #!/usr/bin/perl
-# $Id: XML_Client.pm,v 1.106 2005/04/27 17:36:58 epirogov Exp $
+# $Id: XML_Client.pm,v 1.110 2006/03/21 00:04:24 sbelikov Exp $
 #       .Copyright (C)  2000 TUCOWS.com Inc.
 #       .Created:       11/19/1999
 #       .Contactid:     <admin@vpop.net>
@@ -487,6 +487,19 @@ sub validate_contacts {
 					billing => $default_contact,
 					tech => $default_contact,
 				    },
+				    uk => {
+					owner=> $default_contact,
+					admin=> {
+					    email => "E-Mail",
+					    first_name => "First Name",
+					    last_name => "Last Name",
+					},
+					billing=> {
+					    email => "E-Mail",
+					    first_name => "First Name",
+					    last_name => "Last Name",
+					},
+				    },
 				    ca => {
 					owner => {
 					    org_name=>'Organization Name',
@@ -494,6 +507,14 @@ sub validate_contacts {
 					admin => $default_contact,
 					tech => $default_contact,
 				    },
+				    eu => {
+				        owner => $default_contact,	
+					tech => $default_contact,
+				    },
+				    be => {
+                                        owner => $default_contact,
+                                        tech => $default_contact,
+                                    },
 				    de => {
 					owner=> $default_contact,
 					admin => {
@@ -541,6 +562,12 @@ sub validate_contacts {
 			      owner => "",
 			      admin =>"Admin",
 			  },
+                          eu => {
+                              owner => "Owner",
+                          },
+                          be => {
+                              owner => "Owner",
+                          },
 			  name => {
 			      owner => "",
 			      billing => "Billing",
@@ -553,6 +580,7 @@ sub validate_contacts {
 			      admin => "Admin",
 			      billing => "Zone",
 			  },
+
 			  );
 			  
 
